#-------------------------------------------------------------.
# カレント形状でのキーフレームとして、指定のポーズを反映.
# @param[in]  f_location     カレントパス (string).
# @param[in]  select_index   リスト上のポーズのインデックス.
# @param[in]  used_humanIK   HumanIKのボーンとして認識するか (true/false).
#-------------------------------------------------------------.
import urllib
import os
import os.path

SAVE_FILE_NAME = 'pose_data.txt'

select_index = int(select_index)

if used_humanIK == 'true':
	used_humanIK = True
else:
	used_humanIK = False;

currentSequence = xshade.scene().sequence_value

# --------------------------------------------------------------.
# 指定のボーン名があれば、オフセット/回転をキーフレーム登録.
# --------------------------------------------------------------.
def setKeyframe (shape, boneName, boneOffset, boneRotation):
	if shape.type == 2 and (shape.part_type == 10 or shape.part_type == 16):
		name1 = shape.name
		name2 = boneName

		# HumanIK形式の場合は「xxx_Hips」などの「Hips」で判別する.
		if used_humanIK:
			nIndex1 = name1.rfind('_')
			nIndex2 = name2.rfind('_')
			if nIndex1 > 0 and nIndex2 > 0:
				name1 = name1[(nIndex1+1):]
				name2 = name2[(nIndex2+1):]

		if name1 == name2:
			mIndex = shape.motion.create_motion_point(currentSequence)
			if mIndex >= 0:
				mp = shape.motion.get_motion_point(mIndex)
				mp.offset   = boneOffset
				mp.rotation = boneRotation

	if shape.has_son:
		s = shape.son
		while s.has_bro:
			s = s.bro
			setKeyframe(s, boneName, boneOffset, boneRotation)

# --------------------------------------------------------------.
# 指定のボーン名のものを探して、キーフレーム登録.
# [ボーン1] オフセット  ,回転のクォータニオン
# となっているのを分解.
# --------------------------------------------------------------.
def parseAndSetKeyframe (poseName, lineStr):
	st_index  = lineStr.find('[')
	end_index = lineStr.find(']')
	if st_index < 0 or end_index < 0:
		return

	# 対象ボーン名.
	boneName = lineStr[(st_index+1):end_index]

	# 数値部をコンマで分割.
	strV = lineStr[(end_index + 1):]
	numList = strV.split(',')
	if len(numList) != 7:
		return

	boneOffset   = [float(numList[0]), float(numList[1]), float(numList[2])]
	boneRotation = [float(numList[3]), float(numList[4]), float(numList[5]), float(numList[6])]

	# カレント形状より、boneNameと同じボーン名があれば、それにキーフレームを割り当て.
	shape = xshade.scene().active_shape()

	# 同じボーン名が存在すれば、キーフレーム登録.
	setKeyframe(shape, boneName, boneOffset, boneRotation)

# --------------------------------------------------------------.

# ファイルを開く.
loadFile = urllib.unquote(f_location) + '/datas/' + SAVE_FILE_NAME
if os.path.exists(loadFile) == True:
	f = open(loadFile, 'r')

	index = -1
	lineStr = f.readline()
	while lineStr:
		lineStr = lineStr.rstrip()		# 行末の改行や空白を削除.
		if len(lineStr) != 0:
			# ポーズ名の取得.
			poseName = ''
			if lineStr[0] == '#':
				poseName = lineStr[1:]
				poseName = poseName.lstrip()
				index += 1

			if index == select_index:
				if lineStr[0] == '[':
					# [ボーン1] 0.0,0.0,0.0  ,1.0,0.0,0.0,0.0  と格納されているボーン情報を.
					# キーフレームとして登録.
					parseAndSetKeyframe(poseName, lineStr)

		lineStr = f.readline()

	# ファイルを閉じる.
	f.close()

result = ''
